@@ -9,11 +9,11 @@
     :license: BSD, see LICENSE for details.
 
 '''
-VERSION = '0.2'
+VERSION = '0.3'
 __version__ = VERSION
 
-from .link import TCPLink, SerialLink, UDPLink
-from .logger import LOGGER
+from .link import TCPLink, SerialLink, UDPLink, GSMLink
+from .logger import LOGGER, active_logger
 
 
 def link_from_url(url):
@@ -23,6 +23,10 @@ def link_from_url(url):
     try:
         if len(args) > 1:
             mode = args[0].lower()
+            if mode == "gsm":
+                phone = args[1]
+                parent_link = link_from_url(':'.join(args[2:]))
+                link = GSMLink(phone, parent_link)
             if mode == "tcp" or mode == "udp":
                 host = args[1]
                 port = int(args[2])
@@ -45,7 +49,7 @@ def link_from_url(url):
                     parity = link_args[3][2]
                     stopbits = int(link_args[3][3])
                     link = SerialLink(port, baudrate, bytesize, parity,
-                                            stopbits, timeout)
+                                      stopbits, timeout)
     except:
         pass
     if link is None:
